package org.hornetq.jms.example;

import java.util.Hashtable;

import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.jms.MessageProducer;
import javax.jms.Queue;
import javax.jms.Session;
import javax.jms.TextMessage;
import javax.naming.Context;
import javax.naming.InitialContext;


public class MySender {

	public static void main(final String[] args) throws Exception {
		new MySender().runExample();
	}

	public boolean runExample() throws Exception {
		Connection connection = null;
		InitialContext initialContext = null;
		try {
			Hashtable<String, String> env = new Hashtable<String, String>();
			env.put(Context.INITIAL_CONTEXT_FACTORY, "org.jnp.interfaces.NamingContextFactory");
			env.put(Context.PROVIDER_URL, "jnp://localhost:1099");
			env.put(Context.URL_PKG_PREFIXES, "org.jboss.naming:org.jnp.interfaces");

			initialContext = new InitialContext(env);
			Queue queue = (Queue) initialContext.lookup("/queue/testQ");

			ConnectionFactory cf = (ConnectionFactory) initialContext.lookup("/ConnectionFactory");

			connection = cf.createConnection();

			Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);

			MessageProducer producer = session.createProducer(queue);

			int msgCount = 10;
			
			for (int shard = 1; shard < 10; shard++) {
				
				for (int i = 0; i < msgCount; i++) {
					TextMessage txtMessage = session.createTextMessage("Group-"+shard+" message " + i);
					
					txtMessage.setStringProperty("JMSXGroupID", "Group-"+shard);
					txtMessage.setStringProperty("_HQ_GROUP_ID", "Group-"+shard);
					producer.send(txtMessage);
					System.out.println("Sent message: " + txtMessage.getText());
				}
			}

			System.out.println("all messages are sent");

			connection.start();

			Thread.sleep(2000);

			return true;
		} finally {
			if (initialContext != null) {
				initialContext.close();
			}
			if (connection != null) {
				connection.close();
			}
		}
	}
}
